@@ -1,3 +1,6 @@
+import time
+import numpy as np
+import pandas as pd
 from typing import List, Dict, Tuple
 from .client import FinClient
 from .findata_client import FinDataClient
@@ -361,6 +364,119 @@ def get_history_ohlc(market_name: str, exchang_id: str, instrument_id: str, rang
     )
 
 
+def convert_ohlc_period(ohlc: pd.DataFrame, periodID: str = "60s"):
+    if ohlc is None or ohlc.empty:
+        return pd.DataFrame()
+
+    ohlc_dtypes = get_ohlc_column_types()
+    ohlc = ohlc.astype(ohlc_dtypes)
+
+    if not ohlc.index is pd.DatetimeIndex:
+        # tmp = ohlc["ActionDay"] + ohlc["ActionTime"]
+        # tmp = pd.to_datetime(tmp, format="%Y%m%d%H%M%S")
+        tmp = (ohlc["ActionDay"] + ' ' + ohlc["ActionTime"]).astype('datetime64[s]')
+        ohlc.set_index(tmp, drop=True, inplace=True)
+
+    rs = ohlc.resample(rule=periodID, closed="left", label="left")
+    rs_first = rs.first().dropna(subset=["ExchangeID"])
+    rs_last = rs.last().dropna(subset=["ExchangeID"])
+
+    v = pd.DataFrame()
+    v["ExchangeID"] = rs_last["ExchangeID"]
+    v["InstrumentID"] = rs_last["InstrumentID"]
+    v["TradingDay"] = rs_first["TradingDay"]
+    v["ActionDay"] = rs_first["ActionDay"]
+    v["ActionTime"] = v.index.strftime("%H%M%S")  # 按取样重置时间
+
+    v["Period"] = periodID[0:-1]  # 单位只能是秒's'
+
+    v["OpenPrice"] = rs_first["OpenPrice"]
+    v["HighestPrice"] = rs["HighestPrice"].max().dropna()
+    v["LowestPrice"] = rs["LowestPrice"].min().dropna()
+
+    v["ClosePrice"] = rs_last["ClosePrice"]
+    v["CloseVolume"] = rs["CloseVolume"].sum().dropna()
+    v["CloseBidPrice"] = rs_last["CloseBidPrice"]
+    v["CloseAskPrice"] = rs_last["CloseAskPrice"]
+    v["CloseBidVolume"] = rs_last["CloseBidVolume"]
+    v["CloseAskVolume"] = rs_last["CloseAskVolume"]
+
+    v["TotalTurnover"] = rs_last["TotalTurnover"]
+    v["TotalVolume"] = rs_last["TotalVolume"]
+    v["OpenInterest"] = rs_last["OpenInterest"]
+
+    # v.dropna(subset=["ExchangeID"], inplace=True)
+    v = v.astype(ohlc_dtypes)
+
+    return v
+
+
+def fin_get_history_ohlc(exchang_id: str, instrument_id: str, range: str,
+                         start_date: str, end_date: str):
+    '''
+    获取历史ohlc数据,兼容get_history_ohlc方法返回数据的结构
+    :param exchang_id:交易所编码
+    :param instrument_id:合约编码
+    :param range:周期
+    :param start_date 开始日期
+    :param end_date 结束日期
+    :return:result,msg
+    '''
+    if range.isdigit():
+        rangeN = range
+    elif range.endswith(('s', 'S')):
+        rangeN = range[:-1]
+    else:
+        return [False, 'error range format', None]
+
+    # print(exchang_id,instrument_id,range,start_date,end_date)
+    result, msg, dfohlc = fin_read_ohlc_list(f'{exchang_id}.{instrument_id}', int(start_date), int(end_date), rangeN)
+    if result is False:
+        return [result, msg, dfohlc]
+
+    dfohlc['ActionTimeSpan'] = 0 if dfohlc.empty else (dfohlc['ActionDay'] + ' ' + dfohlc['ActionTime']).astype('datetime64[s]').dt.tz_localize('Asia/Shanghai').map(lambda x: int(x.timestamp() * 1000))
+    dfohlc['TotalVolumeT'] = dfohlc['TotalVolume'].copy()
+    dfohlc['TradingTime'] = dfohlc['ActionTime']
+    dfohlc['Range'] = dfohlc['Period']
+    dfohlc['TotalVolume'] = dfohlc['CloseVolume']
+    return [result, msg, dfohlc]
+
+
+def fin_get_history_ohlc_convert(exchang_id: str, instrument_id: str, range: str,
+                                 start_date: str, end_date: str):
+    '''
+    获取历史ohlc数据,convert from 3S,兼容get_history_ohlc方法返回数据的结构
+    :param exchang_id:交易所编码
+    :param instrument_id:合约编码
+    :param range:周期
+    :param start_date 开始日期
+    :param end_date 结束日期
+    :return:result,msg
+    '''
+    if range.isdigit():
+        rangeS = range + 's'
+    elif range.endswith(('s', 'S')):
+        rangeS = range[:-1] + 's'
+    else:
+        return [False, 'error range format', None]
+
+    # convert from 3S
+    result, msg, dfohlc = fin_read_ohlc_list(f'{exchang_id}.{instrument_id}', int(start_date), int(end_date), '3')
+    if result is False:
+        return [result, msg, dfohlc]
+    # print('s2,time:%f' % (time.time()))
+    if rangeS != '3s':
+        dfohlc = convert_ohlc_period(dfohlc, rangeS)
+    # print('s3,time:%f' % (time.time()))
+    dfohlc['ActionTimeSpan'] = 0 if dfohlc.empty else (dfohlc['ActionDay'] + ' ' + dfohlc['ActionTime']).astype('datetime64[s]').dt.tz_localize('Asia/Shanghai').map(lambda x: int(x.timestamp() * 1000))
+    # print('s4,time:%f' % (time.time()))
+    dfohlc['TotalVolumeT'] = dfohlc['TotalVolume'].copy()
+    dfohlc['TradingTime'] = dfohlc['ActionTime']
+    dfohlc['Range'] = dfohlc['Period']
+    dfohlc['TotalVolume'] = dfohlc['CloseVolume']
+    return [result, msg, dfohlc]
+
+
 def get_ohlc_column_types():
     return FinDataClient.instance().findata_handle().get_ohlc_column_types()
 
@@ -546,7 +662,7 @@ def fin_read_exc_products(exchange_id: List[str], product_id: List[str]):
 
 def fin_read_instruments(exchange_id: List[str] = [], instrument_id: List[str] = [], unicode: List[str] = [], **kwargs):
     '''
-    获取品种信息及交易时段
+    获取合约信息
     :param exchange_id:交易所列表
     :param instrument_id:合约编码
     :param unicode:唯一编码
