@@ -41,6 +41,7 @@ class ChartInitParamData(IData):
         self._ShowDays = 0
         self._BottomLabelList: List[str] = []
         self._LastDataFile: str = ''
+        self._UserData: Dict[str, str] = {}
 
     @property
     def ChartID(self):
@@ -249,3 +250,11 @@ class ChartInitParamData(IData):
     @LastDataFile.setter
     def LastDataFile(self, value: str):
         self._LastDataFile = value
+
+    @property
+    def UserData(self):
+        return self._UserData
+
+    @UserData.setter
+    def UserData(self, value: Dict[str, str]):
+        self._UserData = value
