@@ -64,7 +64,7 @@ class FinDataHandle():
             "MaxMarginSideAlgorithm": bool, "ProductGroupID": str, "StrikePrice": np.float64, "OptionsType": np.int32,
             "UnderlyingInstrID": str, "UnderlyingMultiple": np.float64, "CombinationType": np.int32, "StrikeModeType": np.int32,
             "ObjectPrice": np.float64, "ObjectMarginRatioByMoney": np.float64, "ObjectMarginRatioByVolume": np.float64,
-            "EnsureRatio1": np.float64, "EnsureRatio2": np.float64, "IsCloseToday": bool
+            "EnsureRatio1": np.float64, "EnsureRatio2": np.float64, "IsCloseToday": bool, "Times": str
         }
 
     def set_callback(self, **kwargs):
