@@ -13,6 +13,8 @@ from ..data.trade.get_orders_param_data import GetOrdersParamData
 from ..data.trade.get_tradeorders_param_data import GetTradeOrdersParamData
 from ..data.trade.get_positions_param_data import GetPositionsParamData
 from ..data.trade.read_exc_product_param_data import ReadExcProductParamData
+import numpy as np
+import pandas as pd
 
 
 class TradeHandle():
@@ -23,6 +25,11 @@ class TradeHandle():
     def __init__(self, tsocket: TSocket):
         self.__TSocket = tsocket
         self.__TSocket.set_trade_callback(self.__recv_msg)
+        self.__ExcProduct_Columns_Types = {"ExchangeID": str, "ProductID": str, "ProductName": str,
+                                           "VolumeMultiple": np.float32, "PriceTick": np.float32,
+                                           "MaxMarketOrderVolume": np.int32, "MaxLimitOrderVolume": np.int32,
+                                           "Times": {}}
+        self.__ExcProductTime_Columns_Types = {"StartTime": str, "EndTime": str, "AddDay": np.int32, "InstrumentStatusKind": np.int32}
 
     def __del__(self):
         self.__TSocket.set_trade_callback(None)
@@ -145,8 +152,12 @@ class TradeHandle():
                 rspparams = ReadExcProductParamData()
                 rspparams.un_pack(r.UData)
                 for ot in rspparams.DataList:
+                    if len(ot) >= 7 and isinstance(ot[7], list):
+                        df_pts = pd.DataFrame(ot[7], columns=list(self.__ExcProductTime_Columns_Types.keys()))
+                        ot[7] = df_pts
                     os.append(ot)
-        return os
+        df = pd.DataFrame(os, columns=self.__ExcProduct_Columns_Types.keys())
+        return df
 
     def __unpack_position_list(self, reqrsp: ReqRsp):
         ps = list()
@@ -185,7 +196,7 @@ class TradeHandle():
             self.__ReqRspDict.remove(key)
             return [False, '获取%s数据超时' % fun_name, None]
 
-        return [True, '获取%s数据成功' % fun_name, unpack_func(req_rsp)]
+        return [True, '%s读取成功' % fun_name, unpack_func(req_rsp)]
 
     def __recv_msg(self, msg: MessageData):
         if msg.MID == int(MsgID.Trade_OrderUpdate.value):
