@@ -26,6 +26,9 @@ class MsgID(Enum):
     MSGID_Market_FinReadOHLCList = 200016
     MSGID_Market_FinSaveTickList = 200017
     MSGID_Market_FinReadTickList = 200018
+    MSGID_Market_FinSaveDayList = 200019
+    MSGID_Market_FinReadDayList = 200020
+    MSGID_Market_FinDeleteList = 200021
 
     Trade_SetParams = 300010
     Trade_Open = 300011
@@ -60,6 +63,19 @@ class MsgID(Enum):
     Chart_AddTimeSpanGVList = 400030
     Chart_SaveChartData = 400031
     Chart_LoadChartData = 400032
+    Chart_SelectRect = 400033
+
+    FinData_FinSaveOHLCList = 500001
+    FinData_FinReadOHLCList = 500002
+    FinData_FinSaveTickList = 500003
+    FinData_FinReadTickList = 500004
+    FinData_FinSaveDayList = 500005
+    FinData_FinReadDayList = 500006
+    FinData_FinDeleteList = 500007
+    FinData_ReadExcProducts = 500008
+    FinData_FinReadInstrument = 500009
+    FinData_FinSaveInstrument = 500010
+    FinData_FinReadDBList = 500011
 
 
 class IPacker(object):
