@@ -34,10 +34,12 @@ class ChartInitParamDataPacker(IPacker):
                 bool(self._obj.IsRangeSliderVisible),
                 int(self._obj.ShowDays),
                 self._obj.BottomLabelList,
-                str(self._obj.LastDataFile)]
+                str(self._obj.LastDataFile),
+                dict(self._obj.UserData)]
+
 
     def tuple_to_obj(self, t):
-        if len(t) >= 25:
+        if len(t) >= 27:
             self._obj.ChartID = t[0]
             self._obj.Title = t[1]
             self._obj.Height = t[2]
@@ -64,6 +66,7 @@ class ChartInitParamDataPacker(IPacker):
             self._obj.ShowDays = t[23]
             self._obj.BottomLabelList = t[24]
             self._obj.LastDataFile = t[25]
+            self._obj.UserData = t[26]
 
             return True
         return False
